@@ -1,5 +1,5 @@
 package Devel::IPerl::Kernel::Callback::REPL;
-$Devel::IPerl::Kernel::Callback::REPL::VERSION = '0.009';
+$Devel::IPerl::Kernel::Callback::REPL::VERSION = '0.010';
 use strict;
 use warnings;
 
@@ -129,6 +129,7 @@ sub display_data {
 				msg_type => 'display_data',
 				content => {
 					data => $data_formats,
+					metadata => {},
 				},
 				metadata => {},
 			);
@@ -205,6 +206,10 @@ sub execute_reply {
 sub msg_complete_request {
 	my ($self, $kernel, $msg, $socket ) = @_;
 
+	### send kernel status : busy
+	my $status_busy = Devel::IPerl::Message::Helper->kernel_status( $msg, 'busy' );
+	$kernel->send_message( $kernel->iopub, $status_busy );
+
 	my $code = $msg->content->{code};
 	my $cursor_pos = $msg->content->{cursor_pos};
 
@@ -257,11 +262,19 @@ sub msg_complete_request {
 	);
 	#use DDP; p $complete_reply;
 	$kernel->send_message( $kernel->shell, $complete_reply );
+
+	### send kernel status : idle
+	my $status_idle = Devel::IPerl::Message::Helper->kernel_status( $msg, 'idle' );
+	$kernel->send_message( $kernel->iopub, $status_idle );
 }
 
 sub msg_is_complete_request {
     my ($self, $kernel, $msg, $socket ) = @_;
 
+    ### send kernel status : busy
+    my $status_busy = Devel::IPerl::Message::Helper->kernel_status( $msg, 'busy' );
+    $kernel->send_message( $kernel->iopub, $status_busy );
+
     my $content;
     if ($self->backend->is_complete( $msg->{content}{code} )) {
         $content = {
@@ -278,6 +291,10 @@ sub msg_is_complete_request {
         content => $content,
     );
     $kernel->send_message( $kernel->shell, $is_complete_reply );
+
+    ### send kernel status : idle
+    my $status_idle = Devel::IPerl::Message::Helper->kernel_status( $msg, 'idle' );
+    $kernel->send_message( $kernel->iopub, $status_idle );
 }
 
 
@@ -295,7 +312,7 @@ Devel::IPerl::Kernel::Callback::REPL
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 AUTHOR
 
